@@ -33,7 +33,7 @@ import random
 
 from docopt import docopt
 
-__version__ = '0.3.3'
+__version__ = '0.3.4'
 __author__ = 'Steven Loria'
 __license__ = 'MIT'
 
@@ -56,7 +56,7 @@ INIT_TEMPLATE = '''# -*- coding: utf-8 -*-
 import konch
 
 # TODO: Edit me
-# Available options: 'context', 'banner', 'shell', 'prompt'
+# Available options: 'context', 'banner', 'shell', 'prompt', 'hide_context'
 konch.config({
     'context': {
         'speak': konch.speak
@@ -67,7 +67,7 @@ konch.config({
 
 def execute_file(fname, globals_=None, locals_=None):
     """Executes code in a file. Python 2/3-compatible."""
-    exec(compile(open(fname, "rb").read(), fname, 'exec'), globals_, locals_)
+    exec(compile(open(fname).read(), fname, 'exec'), globals_, locals_)
 
 
 def format_context(context):
